@@ -88,17 +88,21 @@ class PageRecognizer(object):
             cur_page_elements_js = (
                 cur_page_elements_js
                 + """
-image_note.add(new DoneElement(%d / 2, %d / 2, %d / 2, %d / 2, "%s<br/>%s"));
+image_note.add(new DoneElement(%d * 10 / %d, %d * 10 / %d, %d * 10 / %d, %d * 10 / %d, "%s<br/>%s"));
 """
                 % (
                     single_data["crop_img_left"],
+                    cur_page_ratio,
                     single_data["crop_img_top"],
+                    cur_page_ratio,
                     self.page_width
                     - single_data["crop_img_right"]
                     - single_data["crop_img_left"],
+                    cur_page_ratio,
                     self.page_height
                     - single_data["crop_img_bottom"]
                     - single_data["crop_img_top"],
+                    cur_page_ratio,
                     single_element,
                     single_data["recognize_text"],
                 )
